Categorical is defined as factor (and optionally character and logical). This helper is intentionally strict about inputs and does not modify data.
is_categorical_Z_any(sub_data, Z, allow_character = TRUE, allow_logical = TRUE)logical scalar.
data.frame containing the Z columns.
character vector of column names defining the conditioning set.
logical; treat character as categorical. Default TRUE.
logical; treat logical as categorical. Default TRUE.